; Copyright 2009 by Bill Collins
; This code and the corresponding binary game may not be distributed commercially
; without the expressed written consent of the author.

	processor 6502
	include vcs.h

; dasm elite.asm -f3 -o..\roms\aaelite.bin -laaelite.txt -s..\roms\aaelite.sym

;------------------------------------------------------------
; RAM definitions

	SEG.U VARS
	ORG $80

Temp1		ds 1
Temp2		ds 1
Temp3		ds 1
Temp4		ds 1
Temp5		ds 1

Frame	 	ds 1

SoundPtr	ds 1
SoundClk	ds 1

ButtonBuffer	ds 1

; Constants
HorPositions	equ Temp1
HMRegisters	equ HMP0
RESRegisters	equ RESP0

	SEG CODE

; Bank1
;------------------------------------------------------------
	ORG $1000

Bank1Start
	SEI		; Initialize the machine, set interrupt disable.
	CLD		; Clear decimal mode.
	LDX #$FF	; Reset the stack pointer.
	TXS

	INX		; NOTE: sets X to $00
	TXA		; NOTE: sets A to $00

ClearRAM
	STA 0,X		; Clear TIA registers and RAM
	INX		;
	BNE ClearRAM	;
			; Note, the init leaves the background color black.

;----------------------------------------
;Titlescreen setup

Reset
	LDA #$0
	STA COLUBK

	LDA #$1C
	STA COLUPF

	LDA #%00010000
	STA PF1

	LDA #1
	STA CTRLPF

	LDA #%00000110		;3 double wide sprites.
	STA NUSIZ0
	STA NUSIZ1

	JMP GameLoop

;------------------------------------------------------------
GameLoop

VSync			;start vertical retrace

	LDA #2		;bit 1 needs to be 1 to start retrace
	STA VSYNC	;start retrace
	STA WSYNC	;wait a few lines
	STA WSYNC
	LDA #44		;prepare timer to exit blank period
	STA TIM64T	;turn it on
	STA WSYNC	;wait one more
	STA VSYNC	;done with retrace, write 0 to bit 1


;------------------------------------------------------------
VBlank
	INC Frame

	LDA SWCHB		;Read switch settings.
	AND #%00000001
	BNE NoReset		;If bit 0 = 0, then reset has been pushed
ResetHop
	JMP Reset		;so start over

NoReset

	JMP HorizontalMOBPlacement

;----------------------------------------
	align 256

HorizontalMOBPlacement
;Example:
;115 div 16 = 7.3
;115 div 15 = 7.10
;7 + 3 = 10, so 7.10

;Remainder 10 translates to %11010000 in HM register.
;7 in Temp5, %11010000 in A

;Temp5 is the dividend
;A is the remainder

	LDX #4			;Five passes, one for each MOB.

	LDA Frame
	AND #%00000001
	BNE OddFrameOffset

	LDA #33
	STA Temp1
	LDA #49
	STA Temp2
	JMP NextMOB

OddFrameOffset
	LDA #41
	STA Temp1
	LDA #57
	STA Temp2

NextMOB
	LDA HorPositions,X	;4
	LSR			;2 Divide by 16.
	LSR			;2
	LSR			;2
	LSR			;2
	STA Temp5		;3

	LDA HorPositions,X	;4
	AND #%00001111		;2

	CLC			;2 Add the dividend to make div 15.
	ADC Temp5		;3
	CMP #15			;2
	BCC NoOverflow0		;2 or 3 A < 16

	INC Temp5		;5
	SBC #15			;2 Careful!  Carry is set from above.

NoOverflow0
	TAY			;2
	LDA HMTableLookup,Y	;4
	STA HMRegisters,X	;4 47 cycles worst case.

	STA WSYNC

	JSR Wait12

	;Burn 24 cycles here.  Leaves you at the 7th pixel column

	LDY Temp5		;3

PlacementDelay			;Temp5 = 0 must be the 25th cycle.
	DEY			;2
	BPL PlacementDelay	;2 or 3 (5 per pass, 4 on last)

	STA RESRegisters,X	;5

	DEX
	BPL NextMOB

	STA WSYNC
	STA HMOVE

;----------------------------------------


	JMP SwitchToBank2

;------------------------------------------------------------
OverScan
	LDA #35			;Prepare timer to exit OverScan.
	STA TIM64T		;Turn it on.

	LDX SoundPtr
	BEQ DoneSoundCheck

;----------------------------------------
DoneSound
	LDA #0
	STA SoundPtr		;Clear the sound queue.
	STA AUDV0		;Set volume to 0

DoneSoundCheck

;----------------------------------------
	LDA #2
	STA VBLANK
OverScanWait
	LDA INTIM		;check timer for end of VBLANK period
	BNE OverScanWait	;loop until it reaches 0

	INC SoundClk

	JMP GameLoop		;
Wait12	RTS			; This RTS is used for the Wait12 cycles return.

;------------------------------------------------------------
QueueSound
	STA SoundPtr
	LDA #0			  ;Reset the sound Fx Clock.
	STA SoundClk
	RTS

;------------------------------------------------------------

	align 256

; This is used for HMOVE horizontal placement.
HMTableLookup
	.byte #%01110000
	.byte #%01100000
	.byte #%01010000
	.byte #%01000000
	.byte #%00110000
	.byte #%00100000
	.byte #%00010000
	.byte #%00000000
	.byte #%11110000
	.byte #%11100000
	.byte #%11010000
	.byte #%11000000
	.byte #%10110000
	.byte #%10100000
	.byte #%10010000
	.byte #%10000000

;------------------------------------------------------------
	ORG $1FEC
SwitchToBank2
	LDA $1FF9		;1FEC
	JMP Bank1Start		;1FEF Reset return from Bank2.
	NOP			;1FF2
	NOP			;1FF3
	NOP			;1FF4
	JMP OverScan		;1FF5 Bank1 return vector.

	NOP			;1FF8 These 2 addresses are reserved for bankswitching.
	NOP			;1FF9

	NOP			;1FFA
	NOP			;1FFB

	.word	Bank1Start	;1FFC Reset vector
	.word	Bank1Start	;1FFE IRQ vector

;------------------------------------------------------------
; Bank2
;------------------------------------------------------------
	ORG $2000
	RORG $1000

Bank2Start

	LDY #83

	LDA #%11111111
	STA PF2
	LDA #%00011111
	STA PF1

	LDA #$0E		;White.
	STA COLUP0
	STA COLUP1

;------------------------------------------------------------
VBlankWait
	LDA INTIM	;check timer for end of VBLANK period
	BNE VBlankWait	;loop until it reaches 0
	STA WSYNC	;newline
	STA VBLANK	;end screen blank

;------------------------------------------------------------

TheKernel

	SEC			;2	Flag for first data pass.

	JSR Wait12b		;12
	JSR Wait12b		;12
	JSR Wait12b		;12
	JSR Wait12b		;12
	NOP

	LDA #0
	STA PF2
	LDA #%00010000
	STA PF1

	LDA Frame
	AND #%00000001
	BNE OddScanLineLoop

;----------------------------------------
EvenScanLineLoop
	STA WSYNC		;3

	LDA VideoRAMByte0,Y	;4
	STA GRP0		;3 7

	LDA VideoRAMByte2,Y	;4
	STA GRP1		;3 14

	JSR Wait12b		;12
	LDA Temp1		;3 29

	LDA VideoRAMByte4,Y	;4
	STA GRP0		;3 36

	LDA VideoRAMByte6,Y	;4
	STA GRP1		;3 43

	LDA VideoRAMByte8,Y	;4
	STA GRP0		;3 50

	LDA VideoRAMByte10,Y	;4
	STA GRP1		;3 57

	BCC DoneWithData0	;3
	CLC			;2
	BCC EvenScanLineLoop	;3 Reuse the data on a second pass.

DoneWithData0
	SEC			;2
	DEY			;2
	BPL EvenScanLineLoop	;5 62

	JMP DoneBitMap

;----------------------------------------
OddScanLineLoop
	STA WSYNC		;3

	LDA VideoRAMByte1,Y	;4
	STA GRP0		;3 7

	LDA VideoRAMByte3,Y	;4
	STA GRP1		;3 14

	JSR Wait12b		;12
	NOP
	NOP
	NOP

	LDA VideoRAMByte5,Y	;4
	STA GRP0		;3 36

	LDA VideoRAMByte7,Y	;4
	STA GRP1		;3 43

	LDA VideoRAMByte9,Y	;4
	STA GRP0		;3 50

	LDA VideoRAMByte11,Y	;4
	STA GRP1		;3 57

	BCC DoneWithData1	;3
	CLC			;2
	BCC OddScanLineLoop	;3 Reuse the data on a second pass.

DoneWithData1
	SEC			;2
	DEY			;2
	BPL OddScanLineLoop	;5 62

DoneBitMap
	STA WSYNC		;3

	LDA #0			;2
	STA GRP0		;3
	STA GRP1		;3

	LDA #%00011111		;2
	STA PF1			;3
	LDA #%11111111		;2
	STA PF2			;3

	JSR Wait12b		;12
	LDA Temp1		;3
	STA RESP0

	STA WSYNC

	LDA #0			;2
	STA PF2			;3
	LDA #%00011100		;2
	STA PF1			;3

	LDA #$70		;2 Blue
	STA COLUP1		;3

	NOP
	NOP
	NOP
	JSR Wait12b
	STA RESP1

	LDY #15
BottomLoop
	STA WSYNC
	LDA SightGfx,Y		;4
	STA GRP1		;3 7

	LDA SideTarget,Y	;4
	STA GRP0		;3 14

	JSR Wait12b		;12 26
	NOP			;2
	NOP			;2
	NOP			;2
	NOP			;2
	NOP			;2
	NOP			;2 34

	LDA ForwardTarget,Y	;4
	STA GRP0		;3

	LDA TopTarget,Y		;4
	STA GRP0		;3

	DEY
	BPL BottomLoop

	STA WSYNC
	LDA #0
	STA GRP0
	STA GRP1

	LDA #%00011111		;2
	STA PF1			;3
	LDA #%11111111		;2
	STA PF2			;3

	LDY #7

BottomLoop2
	STA WSYNC
	LDA #0
	STA PF1
	STA PF2
	DEY
	BNE BottomLoop2

	JMP SwitchToBank1Normal

Wait12b
	RTS
;------------------------------------------------------------

	align 256

VideoRAMByte0
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00000010
	.byte #%00000111
	.byte #%00000010
	.byte #%00000001
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000

VideoRAMByte1
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00111011
	.byte #%00100010
	.byte #%00100010
	.byte #%00100010
	.byte #%00100011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00000010
	.byte #%00001100
	.byte #%00010001
	.byte #%01100000
	.byte #%10000000
	.byte #%00000001
	.byte #%11111111
	.byte #%00000010
	.byte #%10000010
	.byte #%01000010
	.byte #%00100010
	.byte #%00011010
	.byte #%00000110
	.byte #%00000011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00011101
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000

VideoRAMByte2
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10101011
	.byte #%10101010
	.byte #%10111010
	.byte #%10101010
	.byte #%10010011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000011
	.byte #%00001100
	.byte #%00110000
	.byte #%11000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11000000
	.byte #%11000000
	.byte #%00000011
	.byte #%00011100
	.byte #%11100000
	.byte #%11000000
	.byte #%11111111
	.byte #%00011100
	.byte #%00000011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11000000
	.byte #%00111111
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11011101
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000

	align 256

VideoRAMByte3
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000010
	.byte #%10000010
	.byte #%10000010
	.byte #%10000010
	.byte #%00000011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00000110
	.byte #%00011000
	.byte #%01100001
	.byte #%10000001
	.byte #%00000001
	.byte #%00000001
	.byte #%00000001
	.byte #%00000000
	.byte #%00000000
	.byte #%00000011
	.byte #%00011100
	.byte #%11100000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11100000
	.byte #%00011111
	.byte #%10000000
	.byte #%01110000
	.byte #%00001110
	.byte #%00000001
	.byte #%00000000
	.byte #%00000000
	.byte #%11111110
	.byte #%00000001
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00000001
	.byte #%11000001
	.byte #%00000001
	.byte #%00000001
	.byte #%00000000
	.byte #%00000000

VideoRAMByte4
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10111011
	.byte #%10100011
	.byte #%10110011
	.byte #%10100010
	.byte #%00111010
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000011
	.byte #%00001100
	.byte #%00110001
	.byte #%01000111
	.byte #%10001001
	.byte #%00110001
	.byte #%11000001
	.byte #%00000001
	.byte #%00000110
	.byte #%00011000
	.byte #%01100000
	.byte #%10000011
	.byte #%00001100
	.byte #%01110000
	.byte #%10000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11100000
	.byte #%00011111
	.byte #%00000000
	.byte #%00000000
	.byte #%11000000
	.byte #%00111100
	.byte #%00000011
	.byte #%00000000
	.byte #%11111000
	.byte #%00000111
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11000001
	.byte #%00000001
	.byte #%10000001
	.byte #%00000001
	.byte #%11000001
	.byte #%00000000
	.byte #%00000000

VideoRAMByte5
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10000011
	.byte #%10000010
	.byte #%10000010
	.byte #%10000010
	.byte #%10000011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000011
	.byte #%00001100
	.byte #%00110001
	.byte #%11000110
	.byte #%00000100
	.byte #%00000100
	.byte #%00000100
	.byte #%00000100
	.byte #%00000111
	.byte #%00000100
	.byte #%00000000
	.byte #%00000001
	.byte #%00000110
	.byte #%00011000
	.byte #%01100000
	.byte #%10010000
	.byte #%00001000
	.byte #%00000100
	.byte #%00000100
	.byte #%00000010
	.byte #%00000001
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11100000
	.byte #%00011111
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10000000
	.byte #%01110000
	.byte #%00001110
	.byte #%11110001
	.byte #%00001111
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11000001
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00000000
	.byte #%00000000

	align 256

VideoRAMByte6
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10111010
	.byte #%00101010
	.byte #%00101011
	.byte #%00101011
	.byte #%10111011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00001110
	.byte #%00110000
	.byte #%11000000
	.byte #%00001100
	.byte #%00110100
	.byte #%11000100
	.byte #%00000100
	.byte #%00000100
	.byte #%00011000
	.byte #%00100000
	.byte #%11000011
	.byte #%00001100
	.byte #%00010000
	.byte #%01100000
	.byte #%10000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10000000
	.byte #%01000000
	.byte #%00100000
	.byte #%00010000
	.byte #%00001000
	.byte #%00001000
	.byte #%00000100
	.byte #%11100010
	.byte #%00011111
	.byte #%00000001
	.byte #%00000001
	.byte #%00000001
	.byte #%00000001
	.byte #%00000010
	.byte #%11000010
	.byte #%11111010
	.byte #%00111111
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11000000
	.byte #%10000000
	.byte #%10000000
	.byte #%10000000
	.byte #%11000001
	.byte #%00000000
	.byte #%00000000

VideoRAMByte7
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10101010
	.byte #%10101010
	.byte #%10111011
	.byte #%10111010
	.byte #%10111001
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000111
	.byte #%00011000
	.byte #%01100000
	.byte #%10000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00000110
	.byte #%00011000
	.byte #%00100000
	.byte #%11000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00000010
	.byte #%00000010
	.byte #%00000100
	.byte #%00000100
	.byte #%00001000
	.byte #%00001000
	.byte #%00010000
	.byte #%00100000
	.byte #%00100000
	.byte #%01000000
	.byte #%01000000
	.byte #%10000000
	.byte #%10000000
	.byte #%11111111
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000111
	.byte #%00011000
	.byte #%11100000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10000001
	.byte #%10000001
	.byte #%10000001
	.byte #%10000001
	.byte #%11000001
	.byte #%00000000
	.byte #%00000000

VideoRAMByte8
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10101011
	.byte #%10101010
	.byte #%10101010
	.byte #%10101010
	.byte #%00110011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000011
	.byte #%00001100
	.byte #%00110000
	.byte #%11000001
	.byte #%00000011
	.byte #%00000011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000011
	.byte #%00001100
	.byte #%00010000
	.byte #%01100001
	.byte #%10000001
	.byte #%00000010
	.byte #%00000100
	.byte #%00000100
	.byte #%00001000
	.byte #%00001000
	.byte #%00010000
	.byte #%00010000
	.byte #%00100000
	.byte #%01000000
	.byte #%01000000
	.byte #%10000000
	.byte #%10000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11000000
	.byte #%00111111
	.byte #%00000111
	.byte #%00011000
	.byte #%11100000
	.byte #%10000000
	.byte #%01000000
	.byte #%00100000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11000000
	.byte #%00000000
	.byte #%10000011
	.byte #%00000000
	.byte #%11000000
	.byte #%00000000
	.byte #%00000000

	align 256

VideoRAMByte9
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00111010
	.byte #%10100010
	.byte #%10110011
	.byte #%10100010
	.byte #%00111011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000111
	.byte #%00011000
	.byte #%11100000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%10000010
	.byte #%10000100
	.byte #%00001000
	.byte #%00010000
	.byte #%00111111
	.byte #%11100000
	.byte #%01100000
	.byte #%10100000
	.byte #%10100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100000
	.byte #%00100001
	.byte #%00100001
	.byte #%00100010
	.byte #%00100010
	.byte #%00100100
	.byte #%00100100
	.byte #%00101000
	.byte #%00101000
	.byte #%00110000
	.byte #%00110000
	.byte #%00100000
	.byte #%00100000
	.byte #%11000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10111011
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000

VideoRAMByte10
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10010000
	.byte #%10000000
	.byte #%00011000
	.byte #%10001000
	.byte #%00111000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000110
	.byte #%00011110
	.byte #%11101001
	.byte #%00010001
	.byte #%00100001
	.byte #%01000001
	.byte #%10000000
	.byte #%10000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%11100000
	.byte #%00011111
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000001
	.byte #%00000001
	.byte #%00000010
	.byte #%00000010
	.byte #%00000100
	.byte #%00000100
	.byte #%00001000
	.byte #%00001000
	.byte #%00010000
	.byte #%00010000
	.byte #%00100000
	.byte #%00100000
	.byte #%01000000
	.byte #%01000000
	.byte #%10000000
	.byte #%10000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10111000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000

VideoRAMByte11
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%10000000
	.byte #%10000000
	.byte #%10000000
	.byte #%01000000
	.byte #%01000000
	.byte #%01000000
	.byte #%01000000
	.byte #%00100000
	.byte #%11100000
	.byte #%01000000
	.byte #%01000000
	.byte #%10000000
	.byte #%10000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000

	align 256

SightGfx
	.byte #%00000000
	.byte #%00010000
	.byte #%00000000
	.byte #%00010000
	.byte #%00000000
	.byte #%00010000
	.byte #%00000000
	.byte #%00010000
	.byte #%10101010
	.byte #%00010000
	.byte #%00000000
	.byte #%00010000
	.byte #%00000000
	.byte #%00010000
	.byte #%00000000
	.byte #%00010000

SideTarget
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000010
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000

ForwardTarget
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00010000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000

TopTarget
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00000000
	.byte #%00010000
	.byte #%00000000


;------------------------------------------------------------
	ORG $2FEB
	RORG $1FEB

	NOP		;2FEB
SwitchToBank1Reset
	LDA $1FF8	;2FEC Switch for hard reset.

NormalBank2Entry
	JMP Bank2Start	;2FEF

SwitchToBank1Normal
	LDA $1FF8	;2FF2 Normal bankswitch return.
	NOP		;2FF5
	NOP		;2FF6
	NOP		;2FF7

	NOP		;2FF8 These 2 addresses are reserved for bankswitching.
	NOP		;2FF9

	NOP		;2FFA
	NOP		;2FFB

	.word	SwitchToBank1Reset	;2FFC Reset vector
	.word	SwitchToBank1Reset	;2FFE IRQ vector


